========
QAlgebra
========

.. image:: https://img.shields.io/badge/github-mabuchilab/qalgebra-blue.svg
   :alt: Source code on Github
   :target: https://github.com/mabuchilab/qalgebra
.. image:: https://img.shields.io/pypi/v/qalgebra.svg
   :alt: QAlgebra on the Python Package Index
   :target: https://pypi.python.org/pypi/qalgebra

.. image:: https://img.shields.io/travis/mabuchilab/qalgebra.svg
   :alt: Travis Continuous Integration
   :target: https://travis-ci.org/mabuchilab/qalgebra
.. image:: https://img.shields.io/badge/appveyor-no%20id-red.svg
   :alt: AppVeyor Continuous Integration
   :target: https://ci.appveyor.com/project/mabuchilab/qalgebra
.. image:: https://img.shields.io/coveralls/github/mabuchilab/qalgebra/develop.svg
   :alt: Coveralls
   :target: https://coveralls.io/github/mabuchilab/qalgebra?branch=develop
.. image:: https://readthedocs.org/projects/qalgebra/badge/?version=latest
   :alt: Documentation Status
   :target: https://qalgebra.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/badge/License-MIT-green.svg
   :alt: MIT License
   :target: https://opensource.org/licenses/MIT

Computer algebra package for quantum mechanics

Development of QAlgebra happens on `Github`_.
You can read the full documentation at `ReadTheDocs`_.


.. _ReadTheDocs: https://qalgebra.readthedocs.io/en/latest/


Installation
------------
To install the latest released version of QAlgebra, run this command in your terminal:

.. code-block:: console

    $ pip install qalgebra

This is the preferred method to install QAlgebra, as it will always install the most recent stable release.

If you don't have `pip`_ installed, the `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


To install the latest development version of QAlgebra from `Github`_.

.. code-block:: console

    $ pip install git+https://github.com/mabuchilab/qalgebra.git@develop#egg=qalgebra



.. _Github: https://github.com/mabuchilab/qalgebra

Usage
-----

To use QAlgebra in a project::

    import qalgebra
